==> gitlab_16.11.6.orig.tar.bz2: gitlab-foss-v16.11.6/app/assets/javascripts/organizations/mock_groups.js <==
/* eslint-disable @gitlab/require-i18n-strings */

// This is temporary mock data that will be removed when completing the following:
// https://gitlab.com/gitlab-org/gitlab/-/issues/420777
// https://gitlab.com/gitlab-org/gitlab/-/issues/421441

export const organizationGroups = [
  {
    id: 'gid://gitlab/Group/29',
    fullPath: 'group/29',
    fullName: 'Commit451',
    parent: null,
    webUrl: 'http://127.0.0.1:3000/groups/Commit451',
    descriptionHtml:
      '<p data-sourcepos="1:1-1:52" dir="auto">Autem praesentium vel ut ratione itaque ullam culpa. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Suspendisse libero sem, congue ut sem id, semper pharetra ante. Sed at dui ac nunc pellentesque congue. Phasellus posuere, nisl non pellentesque dignissim, lacus nisi molestie ex, vel placerat neque ligula non libero. Curabitur ipsum enim, pretium eu dignissim vitae, euismod nec nibh. Praesent eget ipsum eleifend, pellentesque tortor vel, consequat neque. Etiam suscipit dolor massa, sed consectetur nunc tincidunt ut. Suspendisse posuere malesuada finibus. Maecenas iaculis et diam eu iaculis. Proin at nulla sit amet erat sollicitudin suscipit sit amet a libero.</p>',
    avatarUrl: null,
    descendantGroupsCount: 0,
    projectsCount: 3,
    groupMembersCount: 2,
    visibility: 'public',
    userPermissions: {
      removeGroup: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    __typename: 'Group',
  },
  {
    id: 'gid://gitlab/Group/33',
    fullPath: 'group/33',
    fullName: 'Flightjs',
    parent: null,
    webUrl: 'http://127.0.0.1:3000/groups/flightjs',
    descriptionHtml:
      '<p data-sourcepos="1:1-1:60" dir="auto">Ipsa reiciendis deleniti officiis illum nostrum quo aliquam.</p>',
    avatarUrl: null,
    descendantGroupsCount: 4,
    projectsCount: 3,
    groupMembersCount: 1,
    visibility: 'private',
    userPermissions: {
      removeGroup: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    __typename: 'Group',
  },
  {
    id: 'gid://gitlab/Group/24',
    fullPath: 'group/24',
    fullName: 'Gitlab Org',
    parent: null,
    webUrl: 'http://127.0.0.1:3000/groups/gitlab-org',
    descriptionHtml:
      '<p data-sourcepos="1:1-1:64" dir="auto">Dolorem dolorem omnis impedit cupiditate pariatur officia velit.</p>',
    avatarUrl: null,
    descendantGroupsCount: 1,
    projectsCount: 1,
    groupMembersCount: 2,
    visibility: 'internal',
    userPermissions: {
      removeGroup: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    __typename: 'Group',
  },
  {
    id: 'gid://gitlab/Group/27',
    fullPath: 'group/27',
    fullName: 'Gnuwget',
    parent: null,
    webUrl: 'http://127.0.0.1:3000/groups/gnuwgetf',
    descriptionHtml:
      '<p data-sourcepos="1:1-1:47" dir="auto">Culpa soluta aut eius dolores est vel sapiente.</p>',
    avatarUrl: null,
    descendantGroupsCount: 4,
    projectsCount: 2,
    groupMembersCount: 3,
    visibility: 'public',
    userPermissions: {
      removeGroup: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    __typename: 'Group',
  },
  {
    id: 'gid://gitlab/Group/31',
    fullPath: 'group/31',
    fullName: 'Jashkenas',
    parent: null,
    webUrl: 'http://127.0.0.1:3000/groups/jashkenas',
    descriptionHtml: '<p data-sourcepos="1:1-1:25" dir="auto">Ut ut id aliquid nostrum.</p>',
    avatarUrl: null,
    descendantGroupsCount: 3,
    projectsCount: 3,
    groupMembersCount: 10,
    visibility: 'private',
    userPermissions: {
      removeGroup: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    __typename: 'Group',
  },
  {
    id: 'gid://gitlab/Group/22',
    fullPath: 'group/22',
    fullName: 'Toolbox',
    parent: null,
    webUrl: 'http://127.0.0.1:3000/groups/toolbox',
    descriptionHtml:
      '<p data-sourcepos="1:1-1:46" dir="auto">Quo voluptatem magnam facere voluptates alias.</p>',
    avatarUrl: null,
    descendantGroupsCount: 2,
    projectsCount: 3,
    groupMembersCount: 40,
    visibility: 'internal',
    userPermissions: {
      removeGroup: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    __typename: 'Group',
  },
  {
    id: 'gid://gitlab/Group/35',
    fullPath: 'group/35',
    fullName: 'Twitter',
    parent: null,
    webUrl: 'http://127.0.0.1:3000/groups/twitter',
    descriptionHtml:
      '<p data-sourcepos="1:1-1:40" dir="auto">Quae nulla consequatur assumenda id quo.</p>',
    avatarUrl: null,
    descendantGroupsCount: 20,
    projectsCount: 30,
    groupMembersCount: 100,
    visibility: 'public',
    userPermissions: {
      removeGroup: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    __typename: 'Group',
  },
  {
    id: 'gid://gitlab/Group/73',
    fullPath: 'group/73',
    fullName: 'test',
    parent: null,
    webUrl: 'http://127.0.0.1:3000/groups/test',
    descriptionHtml: '',
    avatarUrl: null,
    descendantGroupsCount: 1,
    projectsCount: 1,
    groupMembersCount: 1,
    visibility: 'private',
    userPermissions: {
      removeGroup: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    __typename: 'Group',
  },
  {
    id: 'gid://gitlab/Group/74',
    fullPath: 'group/74',
    fullName: 'Twitter / test subgroup',
    parent: null,
    webUrl: 'http://127.0.0.1:3000/groups/twitter/test-subgroup',
    descriptionHtml: '',
    avatarUrl: null,
    descendantGroupsCount: 4,
    projectsCount: 4,
    groupMembersCount: 4,
    visibility: 'internal',
    userPermissions: {
      removeGroup: false,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    __typename: 'Group',
  },
];

==> gitlab_17.0.8.orig.tar.bz2: gitlab-foss-v17.0.8/app/assets/javascripts/organizations/mock_groups.js <==
/* eslint-disable @gitlab/require-i18n-strings */

// This is temporary mock data that will be removed when completing the following:
// https://gitlab.com/gitlab-org/gitlab/-/issues/420777
// https://gitlab.com/gitlab-org/gitlab/-/issues/421441

export const organizationGroups = [
  {
    id: 'gid://gitlab/Group/29',
    fullPath: 'group/29',
    fullName: 'Commit451',
    parent: null,
    webUrl: 'http://127.0.0.1:3000/groups/Commit451',
    descriptionHtml:
      '<p data-sourcepos="1:1-1:52" dir="auto">Autem praesentium vel ut ratione itaque ullam culpa. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Suspendisse libero sem, congue ut sem id, semper pharetra ante. Sed at dui ac nunc pellentesque congue. Phasellus posuere, nisl non pellentesque dignissim, lacus nisi molestie ex, vel placerat neque ligula non libero. Curabitur ipsum enim, pretium eu dignissim vitae, euismod nec nibh. Praesent eget ipsum eleifend, pellentesque tortor vel, consequat neque. Etiam suscipit dolor massa, sed consectetur nunc tincidunt ut. Suspendisse posuere malesuada finibus. Maecenas iaculis et diam eu iaculis. Proin at nulla sit amet erat sollicitudin suscipit sit amet a libero.</p>',
    avatarUrl: null,
    descendantGroupsCount: 0,
    projectsCount: 3,
    groupMembersCount: 2,
    visibility: 'public',
    userPermissions: {
      removeGroup: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    createdAt: '2023-09-19T14:42:38Z',
    updatedAt: '2024-04-24T03:47:38Z',
    __typename: 'Group',
  },
  {
    id: 'gid://gitlab/Group/33',
    fullPath: 'group/33',
    fullName: 'Flightjs',
    parent: null,
    webUrl: 'http://127.0.0.1:3000/groups/flightjs',
    descriptionHtml:
      '<p data-sourcepos="1:1-1:60" dir="auto">Ipsa reiciendis deleniti officiis illum nostrum quo aliquam.</p>',
    avatarUrl: null,
    descendantGroupsCount: 4,
    projectsCount: 3,
    groupMembersCount: 1,
    visibility: 'private',
    userPermissions: {
      removeGroup: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    createdAt: '2023-09-19T14:42:38Z',
    updatedAt: '2024-04-24T03:47:38Z',
    __typename: 'Group',
  },
  {
    id: 'gid://gitlab/Group/24',
    fullPath: 'group/24',
    fullName: 'Gitlab Org',
    parent: null,
    webUrl: 'http://127.0.0.1:3000/groups/gitlab-org',
    descriptionHtml:
      '<p data-sourcepos="1:1-1:64" dir="auto">Dolorem dolorem omnis impedit cupiditate pariatur officia velit.</p>',
    avatarUrl: null,
    descendantGroupsCount: 1,
    projectsCount: 1,
    groupMembersCount: 2,
    visibility: 'internal',
    userPermissions: {
      removeGroup: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    createdAt: '2023-09-19T14:42:38Z',
    updatedAt: '2024-04-24T03:47:38Z',
    __typename: 'Group',
  },
  {
    id: 'gid://gitlab/Group/27',
    fullPath: 'group/27',
    fullName: 'Gnuwget',
    parent: null,
    webUrl: 'http://127.0.0.1:3000/groups/gnuwgetf',
    descriptionHtml:
      '<p data-sourcepos="1:1-1:47" dir="auto">Culpa soluta aut eius dolores est vel sapiente.</p>',
    avatarUrl: null,
    descendantGroupsCount: 4,
    projectsCount: 2,
    groupMembersCount: 3,
    visibility: 'public',
    userPermissions: {
      removeGroup: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    createdAt: '2023-09-19T14:42:38Z',
    updatedAt: '2024-04-24T03:47:38Z',
    __typename: 'Group',
  },
  {
    id: 'gid://gitlab/Group/31',
    fullPath: 'group/31',
    fullName: 'Jashkenas',
    parent: null,
    webUrl: 'http://127.0.0.1:3000/groups/jashkenas',
    descriptionHtml: '<p data-sourcepos="1:1-1:25" dir="auto">Ut ut id aliquid nostrum.</p>',
    avatarUrl: null,
    descendantGroupsCount: 3,
    projectsCount: 3,
    groupMembersCount: 10,
    visibility: 'private',
    userPermissions: {
      removeGroup: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    createdAt: '2023-09-19T14:42:38Z',
    updatedAt: '2024-04-24T03:47:38Z',
    __typename: 'Group',
  },
  {
    id: 'gid://gitlab/Group/22',
    fullPath: 'group/22',
    fullName: 'Toolbox',
    parent: null,
    webUrl: 'http://127.0.0.1:3000/groups/toolbox',
    descriptionHtml:
      '<p data-sourcepos="1:1-1:46" dir="auto">Quo voluptatem magnam facere voluptates alias.</p>',
    avatarUrl: null,
    descendantGroupsCount: 2,
    projectsCount: 3,
    groupMembersCount: 40,
    visibility: 'internal',
    userPermissions: {
      removeGroup: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    createdAt: '2023-09-19T14:42:38Z',
    updatedAt: '2024-04-24T03:47:38Z',
    __typename: 'Group',
  },
  {
    id: 'gid://gitlab/Group/35',
    fullPath: 'group/35',
    fullName: 'Twitter',
    parent: null,
    webUrl: 'http://127.0.0.1:3000/groups/twitter',
    descriptionHtml:
      '<p data-sourcepos="1:1-1:40" dir="auto">Quae nulla consequatur assumenda id quo.</p>',
    avatarUrl: null,
    descendantGroupsCount: 20,
    projectsCount: 30,
    groupMembersCount: 100,
    visibility: 'public',
    userPermissions: {
      removeGroup: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    createdAt: '2023-09-19T14:42:38Z',
    updatedAt: '2024-04-24T03:47:38Z',
    __typename: 'Group',
  },
  {
    id: 'gid://gitlab/Group/73',
    fullPath: 'group/73',
    fullName: 'test',
    parent: null,
    webUrl: 'http://127.0.0.1:3000/groups/test',
    descriptionHtml: '',
    avatarUrl: null,
    descendantGroupsCount: 1,
    projectsCount: 1,
    groupMembersCount: 1,
    visibility: 'private',
    userPermissions: {
      removeGroup: true,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    createdAt: '2023-09-19T14:42:38Z',
    updatedAt: '2024-04-24T03:47:38Z',
    __typename: 'Group',
  },
  {
    id: 'gid://gitlab/Group/74',
    fullPath: 'group/74',
    fullName: 'Twitter / test subgroup',
    parent: null,
    webUrl: 'http://127.0.0.1:3000/groups/twitter/test-subgroup',
    descriptionHtml: '',
    avatarUrl: null,
    descendantGroupsCount: 4,
    projectsCount: 4,
    groupMembersCount: 4,
    visibility: 'internal',
    userPermissions: {
      removeGroup: false,
    },
    maxAccessLevel: {
      integerValue: 30,
    },
    createdAt: '2023-09-19T14:42:38Z',
    updatedAt: '2024-04-24T03:47:38Z',
    __typename: 'Group',
  },
];
